from pulumi import ResourceOptions
from typing import Literal, Any, Optional, Mapping
from theia import Theia
from theia.aws.network.vpc import Vpc, VpcSettings

class testBase:
    def __init__(self, 
                 project: str, 
                 stack: str, 
                 region: str, 
                 backend_url: str,
                 ipv4_cidr: str, 
                 settings: Optional[VpcSettings] = VpcSettings(),
                 tags: Optional[Mapping[str, str]] = None):
        
        self.project = project
        self.stack = stack
        self.region = region
        self.backend_url = backend_url
        self.ipv4_cidr = ipv4_cidr
        self.settings = settings
        self.tags = tags

    def infra(self):
        def program():
            vpc = Vpc(resource_name=f"{self.project}-{self.stack}-vpc",
                      settings=self.settings,
                      ipv4_cidr=self.ipv4_cidr,
                      tags=self.tags)
            
        return Theia(project=self.project,
                     stack=self.stack,
                     program=program,
                     region=self.region,
                     backend_url=self.backend_url)
    
    def __call__(self, command: Literal['preview', 'up', 'destroy', 'refresh']) -> Any:
        t = self.infra()
        getattr(t, command)()


